@@ -9,7 +9,7 @@ use Text::Levenshtein::XS;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-24'; # DATE
 our $DIST = 'Sorter-by_similarity'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 sub meta {
     return +{
@@ -59,14 +59,15 @@ Sorter::by_similarity - Sort by most similar to a reference string
 
 =head1 VERSION
 
-This document describes version 0.002 of Sorter::by_similarity (from Perl distribution Sorter-by_similarity), released on 2024-01-24.
+This document describes version 0.003 of Sorter::by_similarity (from Perl distribution Sorter-by_similarity), released on 2024-01-24.
 
 =head1 SYNOPSIS
 
  use Sorter::by_similarity;
 
  my $sorter = Sorter::by_similarity::gen_sorter(string => 'foo');
- my @sorted = $sorter->("food", "foolish", "foo", "bar"); #
+ my @sorted = $sorter->("food", "foolish", "foo", "bar");
+ # => ("foo", "food", "bar", "foolish")
 
 =head1 DESCRIPTION
 
